﻿namespace ElasticSearchRepository
{
    using System;
    using System.Collections.Generic;
    using System.Linq;

    public class DiscoveryRepository : BaseRepository
    {
        public DiscoveryRepository(Uri elastiSearchServerUrl = null)
            : base(elastiSearchServerUrl)
        {
        }

        /// <summary>
        /// Searches all indexes and all fields.
        /// </summary>
        /// <param name="queryTerm">The query term.</param>
        /// <returns>A search results.</returns>
        public List<Tuple<string, string>> SearchAll(string queryTerm)
        {
            var queryResult = this.client.Search<dynamic>(d =>
                d.AllIndices()
                .AllTypes()
                .QueryString(queryTerm));
          
            return queryResult
                .Hits
                .Select(c => new Tuple<string, string>(c.Index, c.Source.name.Value))
                .Distinct()
                .ToList();
        }

        /// <summary>
        /// A fuzzye search.
        /// </summary>
        /// <param name="queryTerm">The query term.</param>
        /// <returns>A search results.</returns>
        public dynamic FuzzySearch(string queryTerm)
        {
            return this.client.Search<dynamic>(d =>
                   d.AllIndices()
                   .AllTypes()
                   .Query(q => q.Fuzzy(f =>
                                       f.Value(queryTerm))));
        }
    }
}
