﻿namespace ElasticSearchRepository
{
    using EnterpriseSearch;
    using Nest;
    using System;

    public class IndexRepository : BaseRepository
    {
        public IndexRepository(Uri elastiSearchServerUrl = null)
            : base(elastiSearchServerUrl)
        {
        }

        /// <summary>
        /// Creates a mapping for marketing documents.
        /// </summary>
        public void CreateMarketingIndex()
        {
            this.client.CreateIndex("marketing", c =>
                c.AddMapping<MarketingDocument>
                (m => m.Properties(ps => ps.Attachment
                                        (a => a.Name(o => o.Document)
                                               .TitleField(t => t.Name(x => x.Name)
                                                                .TermVector(TermVectorOption.WithPositionsOffsets))))));
        }

        /// <summary>
        /// Indexes the data.
        /// </summary>
        /// <param name="clientdata">The data to index.</param>
        /// <param name="indexName">Name of the index.</param>
        /// <param name="mappingType">Type name of the mapping.</param>
        /// <returns>True is index succeded</returns>
        public bool IndexData<T>(T data, string indexName = null, string mappingType = null)
        where T : class, new()

        {
            if (client == null)
            {
                throw new ArgumentNullException("data");
            }

            var result = this.client.Index<T>(data, c => c.Index(indexName).Type(mappingType));
            return result.IsValid;
        }
    }
}
