﻿using Elasticsearch.Net;
using ElasticSearchRepository;
using Nest;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace EnterpriseSearch
{
    class Program
    {
        static void Main(string[] args)
        {

            ElasticClient c = new ElasticClient();
            c.DeleteIndex(d => d.AllIndices(true));

            var indexRepository = new IndexRepository();
            indexRepository.CreateMarketingIndex();

            var clients = GetClientsMock();
            clients.ForEach((client) =>
            {
                indexRepository.IndexData<Client>(client, "clients");
            });


            var documents = GetMarketingDocumentsMock();
            documents.ForEach((document) =>
            {
                indexRepository.IndexData<MarketingDocument>(document, "marketing");
            });
        }

        /// <summary>
        /// Encodes the file as Base64 string.
        /// </summary>
        /// <param name="filePath">The file path.</param>
        /// <returns>A base64 encoded file.</returns>
        private static string EncodeFile(string filePath)
        {
            var fs = new FileStream(filePath, FileMode.Open, FileAccess.Read);
            var filebytes = new byte[fs.Length];
            fs.Read(filebytes, 0, Convert.ToInt32(fs.Length));
            var encodedData = Convert.ToBase64String(filebytes, Base64FormattingOptions.InsertLineBreaks);

            return encodedData;
        }

        private static List<Client> GetClientsMock()
        {
            return new List<Client>()
            { 
             new Client(){ Id = 1, Name="Jack", Surname="Black", Email="john.black@scrummers.com", Company =  "Scrum"},
             new Client(){ Id = 2, Name="Jack", Surname="White", Email="jwhite@externals.com", Company =  "Externals"},
            };
        }


        /// <summary>
        ///  A mock for getting a marketing products documents from neetwork share.
        /// </summary>
        /// <returns>A list of marketing documents.</returns>
        private static List<MarketingDocument> GetMarketingDocumentsMock()
        {
            const string scrumTutorialFilePath = "C:\\Scrum guidelines.pdf";
            const string csharpTutorialFilePath = "C:\\csharp.pdf";

            return new List<MarketingDocument>()
            { 
                 new MarketingDocument()
                { 
                    Id = 1,
                    ProductName = "Scrum interactive tutorial",
                    Name = "A scrum tutorial",
                    Document = EncodeFile(scrumTutorialFilePath)
                },
                new MarketingDocument()
                {
                    Id = 2,
                    ProductName = "C# tutorial",
                    Name = "A .NET C# tutorial and repicpes",
                    Document = EncodeFile(csharpTutorialFilePath)
                },
            };
        }
    }
}

